==> ein_drag-0.1.11.tgz: package/src/utils/permission.js <==
import router from '@/router'
import store from '@/store'
import { getParameter } from '@/utils'

let validateUserRole = function(to, from, next) {
  if (!store.state.user.userRoles) {
    // 如果没有角色权限信息，拉取同时处理下
    store
      .dispatch('user/getUserRole')
      .then(() => {
        let routes = store.getters.routes
        if (!routes || routes.length <= 0) {
          store.dispatch('router/generateRouter').then(() => {
            // 动态添加可访问路由表
            router.addRoutes(store.getters.addRoutes) // 动态添加可访问路由表
            next({ ...to, replace: true }) // hack方法 确保addRoutes已完成
          })
        } else {
          next()
        }
      })
      .catch(() => {
        // store.dispatch('user/ssoLogout')
      })
  } else {
    next()
  }
}
let test = true
router.beforeEach(function(to, from, next) {
  // 临时调试代码，回头删除解开注释
  if (test) {
    let userInfo = {
      token:
        'eyJhbGciOiJIUzUxMiJ9.eyJzdWIiOiJhZG1pbiIsImV4cCI6MTYwNTIzNTIxNiwiaWF0IjoxNjA1MTQ4ODE2fQ.5c8QQsx897hNVZtF-okGMVKy8uu_dBhzUbGx_kkm2AV3ZpwXOHm7CK4HJOV1DUUQxYaDER7EBb2EK9ZMqsjJww',
      username: '超级管理员',
      account: 'admin',
      userId: '1'
    }
    sessionStorage.setItem('ngStorage-currentUser', JSON.stringify(userInfo))
    return next()
  }
  if (to.meta.anonymous) {
    next()
  } else if (sessionStorage.getItem('ngStorage-currentUser')) {
    // 如果已登录，走路由处理
    validateUserRole(...arguments)
  } else {
    // 没登录判断是否已经单点登录
    let ticket = getParameter('ticket')
    let code = getParameter('code')
    // 单点登录重定向回来时，url地址后面会携带参数
    if (ticket || code) {
      // 通过url地址后面的参数完成认证过程
      let data = { code: code, ticket: ticket, service: location.origin }
      store.dispatch('user/ssoLogin', data).then((res) => {
        next({ ...to, replace: true })
      })
    } else {
      // 重定向到登录页面(会根据当前系统登录方式决定重定向到常规登录或者单点登录界面)
      // store.dispatch('user/jumpToLogin')
      next({ path: '/login' })
    }
  }
})

==> ein_drag-0.1.18.tgz: package/src/utils/permission.js <==
import router from '@/router'
import store from '@/store'
import { getParameter } from '@/utils'

let validateUserRole = function(to, from, next) {
  if (!store.state.user.userRoles) {
    // 如果没有角色权限信息，拉取同时处理下
    store
      .dispatch('user/getUserRole')
      .then(() => {
        let routes = store.getters.routes
        if (!routes || routes.length <= 0) {
          store.dispatch('router/generateRouter').then(() => {
            // 动态添加可访问路由表
            router.addRoutes(store.getters.addRoutes) // 动态添加可访问路由表
            next({ ...to, replace: true }) // hack方法 确保addRoutes已完成
          })
        } else {
          next()
        }
      })
      .catch(() => {
        // store.dispatch('user/ssoLogout')
      })
  } else {
    next()
  }
}
let test = true
router.beforeEach(function(to, from, next) {
  // 临时调试代码，回头删除解开注释
  if (test) {
    let userInfo = {
      token:
        'eyJhbGciOiJIUzUxMiJ9.eyJzdWIiOiJhZG1pbiIsImV4cCI6MTYwNTE3MjIzMSwiaWF0IjoxNjA1MDg1ODMxfQ.pq8_9pVZk3sANKdRN8NADfTccUL46heKFaooFh8oGOYWyycuLpTgfucdauSDOXpZ4dVdiIHzV02yQxUc3rP_FQ',
      username: '超级管理员',
      account: 'admin',
      userId: '1'
    }
    sessionStorage.setItem('ngStorage-currentUser', JSON.stringify(userInfo))
    return next()
  }
  if (to.meta.anonymous) {
    next()
  } else if (sessionStorage.getItem('ngStorage-currentUser')) {
    // 如果已登录，走路由处理
    validateUserRole(...arguments)
  } else {
    // 没登录判断是否已经单点登录
    let ticket = getParameter('ticket')
    let code = getParameter('code')
    // 单点登录重定向回来时，url地址后面会携带参数
    if (ticket || code) {
      // 通过url地址后面的参数完成认证过程
      let data = { code: code, ticket: ticket, service: location.origin }
      store.dispatch('user/ssoLogin', data).then((res) => {
        next({ ...to, replace: true })
      })
    } else {
      // 重定向到登录页面(会根据当前系统登录方式决定重定向到常规登录或者单点登录界面)
      // store.dispatch('user/jumpToLogin')
      next({ path: '/login' })
    }
  }
})
